@@ -1,7 +1,7 @@
 'use strict';
 const timeZone = require('time-zone');
 
-module.exports = options => {
+const dateTime = options => {
 	options = Object.assign({
 		date: new Date(),
 		local: true,
@@ -9,7 +9,7 @@ module.exports = options => {
 		showMilliseconds: false
 	}, options);
 
-	let date = options.date;
+	let {date} = options;
 
 	if (options.local) {
 		// Offset the date so it will return the correct value when getting the ISO string
@@ -31,3 +31,7 @@ module.exports = options => {
 		.replace(/T/, ' ')
 		.replace(/\..+/, end);
 };
+
+module.exports = dateTime;
+// TODO: Remove this for the next major release
+module.exports.default = dateTime;
