@@ -1,27 +1,27 @@
 import test from 'ava';
-import m from '.';
+import dateTime from '.';
 
 test('main', t => {
-	t.regex(m(), /^[\d-]+ [\d:]+$/);
-	t.regex(m({date: new Date()}), /^[\d-]+ [\d:]+$/);
+	t.regex(dateTime(), /^[\d-]+ [\d:]+$/);
+	t.regex(dateTime({date: new Date()}), /^[\d-]+ [\d:]+$/);
 });
 
 test('showTimeZone option', t => {
-	t.regex(m({showTimeZone: true}), /^[\d-]+ [\d:]+ UTC[-+][\d:]+$/);
+	t.regex(dateTime({showTimeZone: true}), /^[\d-]+ [\d:]+ UTC[-+][\d:]+$/);
 
-	t.regex(m({
+	t.regex(dateTime({
 		local: false,
 		showTimeZone: true
 	}), /^[\d-]+ [\d:]+ UTC$/);
 });
 
 test('showMilliseconds option', t => {
-	t.regex(m({
+	t.regex(dateTime({
 		local: false,
 		showMilliseconds: true
 	}), /^[\d-]+ [\d:]+ \d+ms$/);
 
-	t.regex(m({
+	t.regex(dateTime({
 		local: false,
 		showMilliseconds: true,
 		showTimeZone: true
